---
layout: post
title: Sample post
date: 2020-12-26
topics: stasis
---

This is a sample post for [Stasis](), a static site generator.  Here is the excerpt.

<!--excerpt-->

This is a sample post for [Stasis](), a static site generator.  This is the first paragraph of post content.  The content appearing above the excerpt separator will only be present in the index pages, but of course you can change this by editing the templates.  By default, the post template does not include the excerpt, in case you would like the excerpt to be different from the first paragraph of the post itself.

In the next post, we will showcase some of the basics of Pandoc's markdown.

## heading2

Some more text.

### heading3

And even more.

